The returned values is in a list with two components, while the MLEs are in two system files:
h2The heritability estimate based on 2(rMZ-rDZ), where rMZ and rDZ are the intraclass
correlation coefficients for MZ and DZ twin pairs
seh2The standard error for the above statistic
vname.logthe diagnostic file
vname.outthe output file
References
Williams CJ, Christian JC, Norton JA Jr. (1992) TWINAN90: A FORTRAN program
for conducting ANOVA-based and likelihood-based analyses of twin data. Computer Methods and
Programs in Biomedicine 38:(2-3):167-176
Williams CJ (1993). On the covariance between parameter estimates in models of twin
data. Biometrics. 49(2):557-68